@@ -54,7 +54,7 @@
 #endif
 
 
-static inline int min(int n1, int n2)
+static int min(int n1, int n2)
 {
     return n1 < n2 ? n1 : n2;
 }
